<?php
/**
*
* @copyright (c) 2022, Chris1278, https://christian-esch.de
*
* @license GNU General Public License, version 2 (GPL-2.0)
*
*/

namespace chris1278\jsclock\controller;

class acp_controller
{
	protected $db;
	protected $language;
	protected $request;
	protected $template;
	protected $u_action;

	public function __construct(
		\phpbb\db\driver\driver_interface $db,
		\phpbb\language\language $language,
		\phpbb\request\request $request,
		\phpbb\template\template $template
	)
	{
		$this->db			= $db;
		$this->language		= $language;
		$this->request		= $request;
		$this->template		= $template;
	}

	public function display_options()
	{
		$this->language->add_lang('acp_jsclock', 'chris1278/jsclock');
		add_form_key('chris1278_jsclock_acp');
		$errors = [];

		if ($this->request->is_set_post('submit'))
		{
			if (!check_form_key('chris1278_jsclock_acp'))
			{
				$errors[] = $this->language->lang('FORM_INVALID');
			}
			if (empty($errors))
			{
				$this->write_user_jsclock_anonymous('user_jsclock_time_format', $this->request->variable('acp_user_jsclock_time_format', ''));
				$this->write_user_jsclock_anonymous('user_jsclock_font_color', $this->request->variable('acp_user_jsclock_font_color', ''));
				$this->write_user_jsclock_anonymous('user_jsclock_background_color', $this->request->variable('acp_user_jsclock_background_color', ''));
				trigger_error($this->language->lang('ACP_JSCLCOK_SETTING_SAVED') . adm_back_link($this->u_action));
			}
		}

		$s_errors = !empty($errors);

		if ($this->read_user_jsclock_anonymus('user_jsclock_time_format') == 1)
		{
			$am_pm = date('H');

			if ($am_pm >= 0 && $am_pm <= 11)
			{
				$ampm		= $this->language->lang('ACP_USER_JSCLOCK_TIME_FORMAT_AM');
				$dateampm	= date('H');
			}
			else
			{
				$ampm	= $this->language->lang('ACP_USER_JSCLOCK_TIME_FORMAT_PM');
				$dateampm	= date('H') -12;
			}

			$acp_preview_time		= date('' . $dateampm . ' : i : s') . $ampm;
		}
		else
		{
			$acp_preview_time		= date('H : i : s');
		}

		$this->template->assign_vars([
			'JSCLCOK_S_ERROR'							=> $s_errors,
			'JSCLCOK_ERROR_MSG'							=> $s_errors ? implode('<br />', $errors) : '',
			'ACP_USER_JSCLOCK_TIME_FORMAT'				=> $this->read_user_jsclock_anonymus('user_jsclock_time_format'),
			'ACP_USER_JSCLOCK_FONT_COLOR'				=> $this->read_user_jsclock_anonymus('user_jsclock_font_color'),
			'ACP_USER_JSCLOCK_BACKGROUND_COLOR'			=> $this->read_user_jsclock_anonymus('user_jsclock_background_color'),
			'ACP_TIME'									=> $acp_preview_time,
			'U_ACTION'									=> $this->u_action,
		]);
	}

	public function read_user_jsclock_anonymus($value)
	{
		$sql = 'SELECT ' . $value . '
			FROM ' . USERS_TABLE . '
				 WHERE username_clean = "anonymous"' ;

		$result		= $this->db->sql_query($sql);
		$read_user_jsclock_anonymus	= $this->db->sql_fetchfield($value);
		$this->db->sql_freeresult($result);
		return $read_user_jsclock_anonymus;
	}

	public function write_user_jsclock_anonymous($set_input, $sql_input)
	{
		$sql = 'UPDATE ' . USERS_TABLE . '
			SET ' . $set_input . ' = "' . $this->db->sql_escape($sql_input) . '"
			WHERE username_clean = "anonymous"';
		$this->db->sql_query($sql);
	}

	public function set_page_url($u_action)
	{
		$this->u_action = $u_action;
	}
}
