<?php
/**
*
* @copyright (c) 2022, Chris1278, https://christian-esch.de
*
* @license GNU General Public License, version 2 (GPL-2.0)
*
*/

namespace chris1278\jsclock\event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class main_listener implements EventSubscriberInterface
{
	protected $config;
	protected $language;
	protected $request;
	protected $template;
	protected $user;
	protected $auth;
	protected $php_ext;
	protected $phpbb_root_path;

	public function __construct(
		\phpbb\config\config $config,
		\phpbb\language\language $language,
		\phpbb\request\request $request,
		\phpbb\template\template $template,
		\phpbb\user $user,
		\phpbb\auth\auth $auth,
		$php_ext,
		$phpbb_root_path
	)
	{
		$this->config				= $config;
		$this->language				= $language;
		$this->request				= $request;
		$this->template				= $template;
		$this->user					= $user;
		$this->auth 				= $auth;
		$this->php_ext				= $php_ext;
		$this->phpbb_root_path		= $phpbb_root_path;
	}

	public static function getSubscribedEvents()
	{
		return [
			'core.page_header_after' 				=>	'page_header_after',
			'core.permissions'						=> 'add_permissions',
			'core.user_setup_after'					=>	'user_setup_after',
			'core.ucp_prefs_personal_data'			=>	'ucp_prefs_get_data',
			'core.ucp_prefs_personal_update_data'	=>	'ucp_prefs_set_data',
		];
	}

	public function user_setup_after()
	{
		$this->language->add_lang('jsclock', 'chris1278/jsclock');
	}

	public function add_permissions($event)
	{
		$permissions = $event['permissions'];

		$permissions['u_view_jsclock_time_format'] = ['lang' => 'ACL_VIEW_JSCLOCK_TIME_FORMAT', 'cat' => 'misc'];
		$permissions['u_view_jsclock_font_color'] = ['lang' => 'ACL_VIEW_JSCLOCK_FONT_COLOR', 'cat' => 'misc'];
		$permissions['u_view_jsclock_background_color'] = ['lang' => 'ACL_VIEW_JSCLOCK_BACKGROUND_COLOR', 'cat' => 'misc'];

		$event['permissions'] = $permissions;
	}

	public function page_header_after()
	{
		$this->template->assign_vars([
			'T_JS_USER_CLOCK_FONT_COLOR'			=> $this->user->data['user_jsclock_font_color'],
			'T_JS_USER_CLOCK_BACKGROUND_COLOR'		=> $this->user->data['user_jsclock_background_color'],
			'T_JS_CLOCK_FORMAT_SWITCH'				=> $this->user->data['user_jsclock_time_format'],
		]);
	}

	public function ucp_prefs_get_data($event)
	{
		$error_msg		= [];

		if (!empty($this->request->variable('user_jsclock_font_color', '')))
		{
			if (!preg_match('/^[a-fA-F0-9]+$/', $this->request->variable('user_jsclock_font_color', '')))
			{
				$user_font_color		= $this->request->variable($this->user->data['user_jsclock_font_color'],  (string) $this->user->data['user_jsclock_font_color']);
				$error_msg[] = $this->language->lang('UCP_FONT_COLOR_ERROR');
			}
			else
			{
				$user_font_color		= $this->request->variable('user_jsclock_font_color', (string) $this->user->data['user_jsclock_font_color']);
			}
		}
		else
		{
			$user_font_color			= $this->user->data['user_jsclock_font_color'];
		}

		if (!empty($this->request->variable('user_jsclock_background_color', '')))
		{
			if (!preg_match('/^[a-fA-F0-9]+$/', $this->request->variable('user_jsclock_background_color',  '')))
			{
				$user_background_color		= $this->request->variable($this->user->data['user_jsclock_background_color'] , (string) $this->user->data['user_jsclock_background_color']);
				$error_msg[] = $this->language->lang('UCP_BACKGROUND_COLOR_ERROR');
			}
			else
			{
				$user_background_color		= $this->request->variable('user_jsclock_background_color', (string) $this->user->data['user_jsclock_background_color']);
			}
		}
		else
		{
			$user_background_color			= $this->user->data['user_jsclock_background_color'];

		}

		if ($error_msg)
		{
			$event['error'] = $error_msg;
		}

		$event['data'] = array_merge($event['data'], [
			'user_jsclock_time_format'				=> $this->request->variable('user_jsclock_time_format', (int) $this->user->data['user_jsclock_time_format']),
			'user_jsclock_font_color'				=> $user_font_color,
			'user_jsclock_background_color'			=> $user_background_color,
		]);

		if (!$event['submit'])
		{
			$this->template->assign_vars([

				'USER_JSCLOCK_TIME_FORMAT_AUTH'			=> $this->auth->acl_get('u_view_jsclock_time_format'),
				'USER_JSCLOCK_TIME_FORMAT'				=> $event['data']['user_jsclock_time_format'],
				'USER_JSCLOCK_FONT_COLOR_AUTH'			=> $this->auth->acl_get('u_view_jsclock_font_color'),
				'USER_JSCLOCK_FONT_COLOR'				=> $event['data']['user_jsclock_font_color'],
				'USER_JSCLOCK_BACKGROUND_COLOR_AUTH'	=> $this->auth->acl_get('u_view_jsclock_background_color'),
				'USER_JSCLOCK_BACKGROUND_COLOR'			=> $event['data']['user_jsclock_background_color'],

			]);

		}
	}

	public function ucp_prefs_set_data($event)
	{
		$event['sql_ary'] = array_merge($event['sql_ary'], [
			'user_jsclock_time_format' 				=> $event['data']['user_jsclock_time_format'],
			'user_jsclock_font_color' 				=> $event['data']['user_jsclock_font_color'],
			'user_jsclock_background_color' 		=> $event['data']['user_jsclock_background_color'],
		]);
	}
}
